<template>
  <div class="rightContent">
    <div class="top">
      <SearchCommonView
        :add-title="'新建'"
        :placeholder="'请输入单号'"
        :amount-view="false"
        @addCommonClick="addBtnClick"
        @searchClick="getList"
      />
    </div>
    <div class="list-view">
      <div class="table">
        <TableCommonView
          ref="tableListRef"
          :table-list="tableList"
          @selTableCol="selTableCol"
          @tableRowClick="tableRowClick"
        ></TableCommonView>
      </div>
      <div class="btn-pager">
        <PagerView class="page" :pager-options="pagerOptions" v-on="pagerEvents" />
      </div>
    </div>
    <!-- 新建/编辑 -->
    <AddOverviewDialog
      v-if="editConfig.visible"
      :work-type="workType"
      :edit-common-config="editConfig"
      :add-name="this.$route.params.name"
    />
  </div>
</template>

<script>
import pageMixin from "@/components/makepager/pager/mixin/pageMixin"
import { getOperation } from "@/api/overview/overview"
// import DetailProduct from "@/views/productManage/product/DetailProduct"
import AddOverviewDialog from "@/views/overview/AddOverviewDialog"

export default {
  name: "OverviewListView",
  props: {},
  components: { AddOverviewDialog },
  mixins: [pageMixin],
  computed: {},
  data() {
    return {
      tableList: {},
      showcol: ["从", "至", "联系人", "日期", "来源单据", "状态"],
      searchOptions: [],
      commonDetail: {
        visible: false,
        title: "新建",
        infomation: {}
      },
      editConfig: {
        visible: false,
        title: "新建",
        infomation: {}
      },
      workType: this.$route.params.workType
    }
  },
  created() {
    this.setTable()
    this.getData()
    console.log(this.$route.params.workType)
  },
  methods: {
    setTable() {
      this.tableList = {
        tableInfomation: [],
        selectBox: true,
        showcol: this.showcol,
        allcol: [],
        tableColumn: this.setTableColumn(this.showcol)
      }
      let allcol = []
      for (let i = 0; i < this.tableList.tableColumn.length; i++) {
        if (!this.tableList.tableColumn[i].default) {
          const label = this.tableList.tableColumn[i].label
          allcol.push(label)
        }
      }
      this.tableList.allcol = allcol
    },
    setTableColumn(showcol) {
      let tableColumn = [
        {
          label: "单号",
          prop: "id",
          isShowColumn: true,
          default: true
        },
        {
          label: "从",
          prop: "deviceName",
          isShowColumn: showcol.includes("从"),
          default: false
        },
        {
          label: "至",
          prop: "id",
          isShowColumn: showcol.includes("至"),
          default: false
        },
        {
          label: "联系人",
          prop: "deviceId",
          isShowColumn: showcol.includes("联系人"),
          default: false
        },
        {
          label: "负责人",
          prop: "shopName",
          isShowColumn: showcol.includes("负责人"),
          default: false
        },
        {
          label: "日期",
          prop: "preTime",
          isShowColumn: showcol.includes("日期"),
          default: false,
          date: true
        },
        {
          label: "产品可用性",
          prop: "status",
          isShowColumn: showcol.includes("产品可用性"),
          default: false
        },
        {
          label: "截止日期",
          prop: "faultTime",
          isShowColumn: showcol.includes("截止日期"),
          default: false
        },
        {
          label: "实际日期",
          prop: "shopName",
          isShowColumn: showcol.includes("实际日期"),
          default: false
        },
        {
          label: "来源单据",
          prop: "faultLevel",
          isShowColumn: showcol.includes("来源单据"),
          default: false
        },
        {
          label: "欠单",
          prop: "status",
          isShowColumn: showcol.includes("欠单"),
          default: false
        },
        {
          label: "入库类型",
          prop: "faultTime",
          isShowColumn: showcol.includes("入库类型"),
          default: false
        },
        {
          label: "状态",
          prop: "status",
          width: 120,
          isShowColumn: showcol.includes("状态"),
          default: false,
          status: true
        }
      ]
      return tableColumn
    },
    selTableCol(val) {
      this.showcol = val
      this.tableList.tableColumn = this.setTableColumn(val)
    },
    // 请求数据
    async getData() {
      await getOperation({
        operationTypeId: this.$route.params.id,
        page: this.pagerOptions.currPage,
        pageSize: this.pagerOptions.pageSize
      }).then((res) => {
        console.log(res.data.data)
        if (res.data.code === 200) {
          const list = res.data.data.map((item) => {
            return {
              ...item
            }
          })
          this.tableList.tableInfomation = list || []
          this.pagerOptions.totalCount = res.data.total
        }
      })
    },
    // 搜索
    getList(val) {
      console.log(val)
    },
    // 行点击
    tableRowClick(row) {
      console.log(row)
      this.editConfig.visible = true
      this.editConfig.title = "编辑"
      this.editConfig.infomation = { ...row }
    },
    // 新建
    addBtnClick() {
      this.editConfig.visible = true
      this.editConfig.title = "新建"
    }
  }
}
</script>

<!-- Add "scoped" attribute to limit CSS to this component only -->
<style lang="scss" scoped></style>
